@@ -30,15 +30,14 @@ ncoLexer::ncoLexer(const ANTLR_USE_NAMESPACE(antlr)LexerSharedInputState& state)
 
 void ncoLexer::initLiterals()
 {
-	literals["<<"] = 96;
-	literals["for"] = 49;
-	literals["print"] = 44;
+	literals["<<"] = 95;
+	literals["for"] = 46;
 	literals["defdimunlim"] = 32;
 	literals["where"] = 42;
 	literals["elsewhere"] = 43;
 	literals["continue"] = 39;
 	literals["while"] = 37;
-	literals[">>"] = 97;
+	literals[">>"] = 96;
 	literals["break"] = 38;
 	literals["if"] = 40;
 	literals["else"] = 41;
@@ -201,7 +200,7 @@ ANTLR_USE_NAMESPACE(antlr)RefToken ncoLexer::nextToken()
 			}
 			case 0x40 /* '@' */ :
 			{
-				mSTR_ATT_ID(true);
+				mATT_ID(true);
 				theRetToken=_returnToken;
 				break;
 			}
@@ -1312,6 +1311,11 @@ void ncoLexer::mVAR_NM_QT(bool _createToken) {
 			match(':' /* charlit */ );
 			break;
 		}
+		case 0x20 /* ' ' */ :
+		{
+			match(' ' /* charlit */ );
+			break;
+		}
 		default:
 		{
 			if ( _cnt146>=1 ) { goto _loop146; } else {throw ANTLR_USE_NAMESPACE(antlr)NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
@@ -1335,7 +1339,7 @@ void ncoLexer::mBLASTOUT(bool _createToken) {
 	ANTLR_USE_NAMESPACE(std)string::size_type _saveIndex;
 	
 	matchNot(EOF/*_CHAR*/);
-#line 455 "ncoGrammer.g"
+#line 457 "ncoGrammer.g"
 	
 	// blast out of lexer & parser
 	// Can't use RecognitionException() as 
@@ -1350,7 +1354,7 @@ void ncoLexer::mBLASTOUT(bool _createToken) {
 	ANTLR_USE_NAMESPACE(antlr)RecognitionException re(os.str());
 	throw  ANTLR_USE_NAMESPACE(antlr)TokenStreamRecognitionException(re);
 	
-#line 1354 "ncoLexer.cpp"
+#line 1358 "ncoLexer.cpp"
 	if ( _createToken && _token==ANTLR_USE_NAMESPACE(antlr)nullToken && _ttype!=ANTLR_USE_NAMESPACE(antlr)Token::SKIP ) {
 	   _token = makeToken(_ttype);
 	   _token->setText(text.substr(_begin, text.length()-_begin));
@@ -1392,7 +1396,7 @@ void ncoLexer::mUNUSED_OPS(bool _createToken) {
 	}
 	}
 	}
-#line 471 "ncoGrammer.g"
+#line 473 "ncoGrammer.g"
 	
 	
 	ostringstream os;
@@ -1402,7 +1406,7 @@ void ncoLexer::mUNUSED_OPS(bool _createToken) {
 	ANTLR_USE_NAMESPACE(antlr)RecognitionException re(os.str());
 	throw  ANTLR_USE_NAMESPACE(antlr)TokenStreamRecognitionException(re);
 	
-#line 1406 "ncoLexer.cpp"
+#line 1410 "ncoLexer.cpp"
 	if ( _createToken && _token==ANTLR_USE_NAMESPACE(antlr)nullToken && _ttype!=ANTLR_USE_NAMESPACE(antlr)Token::SKIP ) {
 	   _token = makeToken(_ttype);
 	   _token->setText(text.substr(_begin, text.length()-_begin));
@@ -1426,9 +1430,9 @@ void ncoLexer::mWS(bool _createToken) {
 	case 0x9 /* '\t' */ :
 	{
 		match('\t' /* charlit */ );
-#line 484 "ncoGrammer.g"
+#line 486 "ncoGrammer.g"
 		tab();
-#line 1432 "ncoLexer.cpp"
+#line 1436 "ncoLexer.cpp"
 		break;
 	}
 	case 0xc /* '\14' */ :
@@ -1439,9 +1443,9 @@ void ncoLexer::mWS(bool _createToken) {
 	case 0xa /* '\n' */ :
 	{
 		match('\n' /* charlit */ );
-#line 484 "ncoGrammer.g"
+#line 486 "ncoGrammer.g"
 		newline();
-#line 1445 "ncoLexer.cpp"
+#line 1449 "ncoLexer.cpp"
 		break;
 	}
 	default:
@@ -1450,9 +1454,9 @@ void ncoLexer::mWS(bool _createToken) {
 	}
 	}
 	}
-#line 485 "ncoGrammer.g"
+#line 487 "ncoGrammer.g"
 	_ttype = antlr::Token::SKIP;
-#line 1456 "ncoLexer.cpp"
+#line 1460 "ncoLexer.cpp"
 	if ( _createToken && _token==ANTLR_USE_NAMESPACE(antlr)nullToken && _ttype!=ANTLR_USE_NAMESPACE(antlr)Token::SKIP ) {
 	   _token = makeToken(_ttype);
 	   _token->setText(text.substr(_begin, text.length()-_begin));
@@ -1480,9 +1484,9 @@ void ncoLexer::mCXX_COMMENT(bool _createToken) {
 	_loop154:;
 	} // ( ... )*
 	match('\n' /* charlit */ );
-#line 490 "ncoGrammer.g"
+#line 492 "ncoGrammer.g"
 	_ttype = antlr::Token::SKIP; newline();
-#line 1486 "ncoLexer.cpp"
+#line 1490 "ncoLexer.cpp"
 	if ( _createToken && _token==ANTLR_USE_NAMESPACE(antlr)nullToken && _ttype!=ANTLR_USE_NAMESPACE(antlr)Token::SKIP ) {
 	   _token = makeToken(_ttype);
 	   _token->setText(text.substr(_begin, text.length()-_begin));
@@ -1521,9 +1525,9 @@ void ncoLexer::mC_COMMENT(bool _createToken) {
 			}
 			}
 			}
-#line 497 "ncoGrammer.g"
+#line 499 "ncoGrammer.g"
 			newline();
-#line 1527 "ncoLexer.cpp"
+#line 1531 "ncoLexer.cpp"
 		}
 		else if ((_tokenSet_4.member(LA(1)))) {
 			{
@@ -1538,9 +1542,9 @@ void ncoLexer::mC_COMMENT(bool _createToken) {
 	_loop159:;
 	} // ( ... )*
 	match("*/");
-#line 501 "ncoGrammer.g"
+#line 503 "ncoGrammer.g"
 	_ttype = antlr::Token::SKIP;
-#line 1544 "ncoLexer.cpp"
+#line 1548 "ncoLexer.cpp"
 	if ( _createToken && _token==ANTLR_USE_NAMESPACE(antlr)nullToken && _ttype!=ANTLR_USE_NAMESPACE(antlr)Token::SKIP ) {
 	   _token = makeToken(_ttype);
 	   _token->setText(text.substr(_begin, text.length()-_begin));
@@ -1577,9 +1581,9 @@ void ncoLexer::mNUMBER_DOT(bool _createToken) {
 	}
 	
 	}
-#line 508 "ncoGrammer.g"
+#line 510 "ncoGrammer.g"
 	_ttype = NCAP_DOUBLE;
-#line 1583 "ncoLexer.cpp"
+#line 1587 "ncoLexer.cpp"
 	{
 	switch ( LA(1)) {
 	case 0x44 /* 'D' */ :
@@ -1603,9 +1607,9 @@ void ncoLexer::mNUMBER_DOT(bool _createToken) {
 		}
 		}
 		}
-#line 509 "ncoGrammer.g"
+#line 511 "ncoGrammer.g"
 		_ttype = NCAP_DOUBLE;
-#line 1609 "ncoLexer.cpp"
+#line 1613 "ncoLexer.cpp"
 		break;
 	}
 	case 0x46 /* 'F' */ :
@@ -1629,9 +1633,9 @@ void ncoLexer::mNUMBER_DOT(bool _createToken) {
 		}
 		}
 		}
-#line 510 "ncoGrammer.g"
+#line 512 "ncoGrammer.g"
 		_ttype = NCAP_FLOAT;
-#line 1635 "ncoLexer.cpp"
+#line 1639 "ncoLexer.cpp"
 		break;
 	}
 	case 0x4c /* 'L' */ :
@@ -1655,9 +1659,9 @@ void ncoLexer::mNUMBER_DOT(bool _createToken) {
 		}
 		}
 		}
-#line 511 "ncoGrammer.g"
+#line 513 "ncoGrammer.g"
 		_ttype = NCAP_DOUBLE;
-#line 1661 "ncoLexer.cpp"
+#line 1665 "ncoLexer.cpp"
 		break;
 	}
 	default:
@@ -1692,9 +1696,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 	}
 	_loop170:;
 	}  // ( ... )+
-#line 516 "ncoGrammer.g"
+#line 518 "ncoGrammer.g"
 	_ttype = NCAP_INT;
-#line 1698 "ncoLexer.cpp"
+#line 1702 "ncoLexer.cpp"
 	{
 	switch ( LA(1)) {
 	case 0x2e /* '.' */ :
@@ -1747,9 +1751,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 		
 		}
 		}
-#line 517 "ncoGrammer.g"
+#line 519 "ncoGrammer.g"
 		_ttype = NCAP_DOUBLE;
-#line 1753 "ncoLexer.cpp"
+#line 1757 "ncoLexer.cpp"
 		break;
 	}
 	case 0x45 /* 'E' */ :
@@ -1758,9 +1762,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 		{
 		mXPN(false);
 		}
-#line 518 "ncoGrammer.g"
+#line 520 "ncoGrammer.g"
 		_ttype = NCAP_DOUBLE;
-#line 1764 "ncoLexer.cpp"
+#line 1768 "ncoLexer.cpp"
 		break;
 	}
 	case 0x53 /* 'S' */ :
@@ -1784,9 +1788,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 		}
 		}
 		}
-#line 520 "ncoGrammer.g"
+#line 522 "ncoGrammer.g"
 		_ttype = NCAP_SHORT;
-#line 1790 "ncoLexer.cpp"
+#line 1794 "ncoLexer.cpp"
 		break;
 	}
 	case 0x42 /* 'B' */ :
@@ -1810,9 +1814,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 		}
 		}
 		}
-#line 521 "ncoGrammer.g"
+#line 523 "ncoGrammer.g"
 		_ttype = NCAP_BYTE;
-#line 1816 "ncoLexer.cpp"
+#line 1820 "ncoLexer.cpp"
 		break;
 	}
 	default:
@@ -1835,9 +1839,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 			}
 			}
 			}
-#line 526 "ncoGrammer.g"
+#line 528 "ncoGrammer.g"
 			_ttype = NCAP_UINT64;
-#line 1841 "ncoLexer.cpp"
+#line 1845 "ncoLexer.cpp"
 		}
 		else if ((LA(1) == 0x55 /* 'U' */  || LA(1) == 0x75 /* 'u' */ ) && (LA(2) == 0x42 /* 'B' */  || LA(2) == 0x62 /* 'b' */ )) {
 			{
@@ -1858,9 +1862,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 			}
 			}
 			}
-#line 522 "ncoGrammer.g"
+#line 524 "ncoGrammer.g"
 			_ttype = NCAP_UBYTE;
-#line 1864 "ncoLexer.cpp"
+#line 1868 "ncoLexer.cpp"
 		}
 		else if ((LA(1) == 0x55 /* 'U' */  || LA(1) == 0x75 /* 'u' */ ) && (LA(2) == 0x53 /* 'S' */  || LA(2) == 0x73 /* 's' */ )) {
 			{
@@ -1881,9 +1885,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 			}
 			}
 			}
-#line 523 "ncoGrammer.g"
+#line 525 "ncoGrammer.g"
 			_ttype = NCAP_USHORT;
-#line 1887 "ncoLexer.cpp"
+#line 1891 "ncoLexer.cpp"
 		}
 		else if ((LA(1) == 0x4c /* 'L' */  || LA(1) == 0x6c /* 'l' */ ) && (LA(2) == 0x4c /* 'L' */  || LA(2) == 0x6c /* 'l' */ )) {
 			{
@@ -1904,9 +1908,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 			}
 			}
 			}
-#line 525 "ncoGrammer.g"
+#line 527 "ncoGrammer.g"
 			_ttype = NCAP_INT64;
-#line 1910 "ncoLexer.cpp"
+#line 1914 "ncoLexer.cpp"
 		}
 		else if ((LA(1) == 0x4c /* 'L' */  || LA(1) == 0x6c /* 'l' */ ) && (true)) {
 			{
@@ -1927,9 +1931,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 			}
 			}
 			}
-#line 519 "ncoGrammer.g"
+#line 521 "ncoGrammer.g"
 			_ttype = NCAP_INT;
-#line 1933 "ncoLexer.cpp"
+#line 1937 "ncoLexer.cpp"
 		}
 		else if ((LA(1) == 0x55 /* 'U' */  || LA(1) == 0x75 /* 'u' */ ) && (true) && (true)) {
 			{
@@ -1950,9 +1954,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 			}
 			
 			}
-#line 524 "ncoGrammer.g"
+#line 526 "ncoGrammer.g"
 			_ttype = NCAP_UINT;
-#line 1956 "ncoLexer.cpp"
+#line 1960 "ncoLexer.cpp"
 		}
 		else {
 		}
@@ -1981,9 +1985,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 		}
 		}
 		}
-#line 528 "ncoGrammer.g"
+#line 530 "ncoGrammer.g"
 		_ttype = NCAP_FLOAT;
-#line 1987 "ncoLexer.cpp"
+#line 1991 "ncoLexer.cpp"
 		break;
 	}
 	case 0x44 /* 'D' */ :
@@ -2007,9 +2011,9 @@ void ncoLexer::mNUMBER(bool _createToken) {
 		}
 		}
 		}
-#line 529 "ncoGrammer.g"
+#line 531 "ncoGrammer.g"
 		_ttype = NCAP_DOUBLE;
-#line 2013 "ncoLexer.cpp"
+#line 2017 "ncoLexer.cpp"
 		break;
 	}
 	default:
@@ -2115,9 +2119,9 @@ void ncoLexer::mVAR_ATT(bool _createToken) {
 	}
 	_loop193:;
 	} // ( ... )*
-#line 537 "ncoGrammer.g"
+#line 541 "ncoGrammer.g"
 	
-	// try to intelligently guess the type to avoid un-necessary function search  
+	// try to intelligently guess the type to avoid un-necessary function search    
 	bool bDoSearch;
 	switch( LA(1) ){
 	case ' ': 
@@ -2152,7 +2156,7 @@ void ncoLexer::mVAR_ATT(bool _createToken) {
 	}             
 	} 
 	
-#line 2156 "ncoLexer.cpp"
+#line 2160 "ncoLexer.cpp"
 	{
 	if ((LA(1) == 0x40 /* '@' */ )) {
 		match('@' /* charlit */ );
@@ -2241,9 +2245,9 @@ void ncoLexer::mVAR_ATT(bool _createToken) {
 		}
 		_loop197:;
 		} // ( ... )*
-#line 573 "ncoGrammer.g"
+#line 577 "ncoGrammer.g"
 		_ttype = ATT_ID;
-#line 2247 "ncoLexer.cpp"
+#line 2251 "ncoLexer.cpp"
 	}
 	else {
 	}
@@ -2269,18 +2273,18 @@ void ncoLexer::mVAR_ATT_QT(bool _createToken) {
 	text.erase(_saveIndex);
 	}
 	mVAR_NM_QT(false);
-#line 579 "ncoGrammer.g"
+#line 583 "ncoGrammer.g"
 	_ttype = VAR_ID;
-#line 2275 "ncoLexer.cpp"
+#line 2279 "ncoLexer.cpp"
 	{
 	switch ( LA(1)) {
 	case 0x40 /* '@' */ :
 	{
 		match('@' /* charlit */ );
 		mVAR_NM_QT(false);
-#line 580 "ncoGrammer.g"
+#line 584 "ncoGrammer.g"
 		_ttype = ATT_ID;
-#line 2284 "ncoLexer.cpp"
+#line 2288 "ncoLexer.cpp"
 		break;
 	}
 	case 0x27 /* '\'' */ :
@@ -2306,9 +2310,9 @@ void ncoLexer::mVAR_ATT_QT(bool _createToken) {
 	_saveIndex=0;
 }
 
-void ncoLexer::mSTR_ATT_ID(bool _createToken) {
+void ncoLexer::mATT_ID(bool _createToken) {
 	int _ttype; ANTLR_USE_NAMESPACE(antlr)RefToken _token; ANTLR_USE_NAMESPACE(std)string::size_type _begin = text.length();
-	_ttype = STR_ATT_ID;
+	_ttype = ATT_ID;
 	ANTLR_USE_NAMESPACE(std)string::size_type _saveIndex;
 	
 	match('@' /* charlit */ );
@@ -2397,9 +2401,9 @@ void ncoLexer::mSTR_ATT_ID(bool _createToken) {
 	}
 	_loop205:;
 	} // ( ... )*
-#line 585 "ncoGrammer.g"
-	_ttype = STR_ATT_ID;
-#line 2403 "ncoLexer.cpp"
+#line 589 "ncoGrammer.g"
+	string an=text.substr(_begin,text.length()-_begin);{ text.erase(_begin); text += "global"+an; };_ttype = ATT_ID;
+#line 2407 "ncoLexer.cpp"
 	if ( _createToken && _token==ANTLR_USE_NAMESPACE(antlr)nullToken && _ttype!=ANTLR_USE_NAMESPACE(antlr)Token::SKIP ) {
 	   _token = makeToken(_ttype);
 	   _token->setText(text.substr(_begin, text.length()-_begin));
@@ -2420,9 +2424,9 @@ void ncoLexer::mSTR_ATT_QT(bool _createToken) {
 	}
 	match('@' /* charlit */ );
 	mVAR_NM_QT(false);
-#line 590 "ncoGrammer.g"
-	_ttype = STR_ATT_ID;
-#line 2426 "ncoLexer.cpp"
+#line 594 "ncoGrammer.g"
+	_ttype = STR_ATT_QT;
+#line 2430 "ncoLexer.cpp"
 	{
 	_saveIndex = text.length();
 	match('\'' /* charlit */ );
@@ -2451,9 +2455,9 @@ void ncoLexer::mDIM_QT(bool _createToken) {
 	match('$' /* charlit */ );
 	text.erase(_saveIndex);
 	mVAR_NM_QT(false);
-#line 597 "ncoGrammer.g"
+#line 601 "ncoGrammer.g"
 	_ttype = DIM_ID;
-#line 2457 "ncoLexer.cpp"
+#line 2461 "ncoLexer.cpp"
 	}
 	{
 	_saveIndex = text.length();
@@ -2465,9 +2469,9 @@ void ncoLexer::mDIM_QT(bool _createToken) {
 		_saveIndex = text.length();
 		match(".size");
 		text.erase(_saveIndex);
-#line 599 "ncoGrammer.g"
+#line 603 "ncoGrammer.g"
 		_ttype = DIM_ID_SIZE;
-#line 2471 "ncoLexer.cpp"
+#line 2475 "ncoLexer.cpp"
 	}
 	else {
 	}
@@ -2574,17 +2578,17 @@ void ncoLexer::mDIM_VAL(bool _createToken) {
 	}
 	_loop217:;
 	} // ( ... )*
-#line 604 "ncoGrammer.g"
+#line 608 "ncoGrammer.g"
 	_ttype = DIM_ID;
-#line 2580 "ncoLexer.cpp"
+#line 2584 "ncoLexer.cpp"
 	{
 	if ((LA(1) == 0x2e /* '.' */ )) {
 		_saveIndex = text.length();
 		match(".size");
 		text.erase(_saveIndex);
-#line 606 "ncoGrammer.g"
+#line 610 "ncoGrammer.g"
 		_ttype = DIM_ID_SIZE;
-#line 2588 "ncoLexer.cpp"
+#line 2592 "ncoLexer.cpp"
 	}
 	else {
 	}
@@ -2653,17 +2657,17 @@ void ncoLexer::mNSTRING(bool _createToken) {
 	_saveIndex = text.length();
 	match('\"' /* charlit */ );
 	text.erase(_saveIndex);
-#line 619 "ncoGrammer.g"
+#line 624 "ncoGrammer.g"
 	_ttype = NSTRING;
-#line 2659 "ncoLexer.cpp"
+#line 2663 "ncoLexer.cpp"
 	{
 	if ((LA(1) == 0x73 /* 's' */ )) {
 		_saveIndex = text.length();
 		match('s' /* charlit */ );
 		text.erase(_saveIndex);
-#line 620 "ncoGrammer.g"
+#line 625 "ncoGrammer.g"
 		_ttype = N4STRING;
-#line 2667 "ncoLexer.cpp"
+#line 2671 "ncoLexer.cpp"
 	}
 	else {
 	}
@@ -2706,7 +2710,7 @@ void ncoLexer::mINCLUDE(bool _createToken) {
 	}
 	mNSTRING(true);
 	f=_returnToken;
-#line 625 "ncoGrammer.g"
+#line 630 "ncoGrammer.g"
 	
 			// ANTLR_USING_NAMESPACE(std)
 			// create lexer to handle include
@@ -2736,7 +2740,7 @@ void ncoLexer::mINCLUDE(bool _createToken) {
 			// of the new instance of this lexer.
 			selector.retry(); // throws TokenStreamRetryException
 			
-#line 2740 "ncoLexer.cpp"
+#line 2744 "ncoLexer.cpp"
 	if ( _createToken && _token==ANTLR_USE_NAMESPACE(antlr)nullToken && _ttype!=ANTLR_USE_NAMESPACE(antlr)Token::SKIP ) {
 	   _token = makeToken(_ttype);
 	   _token->setText(text.substr(_begin, text.length()-_begin));
@@ -2749,33 +2753,33 @@ void ncoLexer::mINCLUDE(bool _createToken) {
 const unsigned long ncoLexer::_tokenSet_0_data_[] = { 0UL, 96UL, 1073741824UL, 268435456UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // % & ^ 
 const ANTLR_USE_NAMESPACE(antlr)BitSet ncoLexer::_tokenSet_0(_tokenSet_0_data_,10);
-const unsigned long ncoLexer::_tokenSet_1_data_[] = { 0UL, 134179584UL, 2281701374UL, 134217726UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
-// ( ) + - . 0 1 2 3 4 5 6 7 8 9 : A B C D E F G H I J K L M N O P Q R 
-// S T U V W X Y Z _ a b c d e f g h i j k l m n o p q r s t u v 
+const unsigned long ncoLexer::_tokenSet_1_data_[] = { 0UL, 134179585UL, 2281701374UL, 134217726UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
+//   ( ) + - . 0 1 2 3 4 5 6 7 8 9 : A B C D E F G H I J K L M N O P Q 
+// R S T U V W X Y Z _ a b c d e f g h i j k l m n o p q r s t 
 const ANTLR_USE_NAMESPACE(antlr)BitSet ncoLexer::_tokenSet_1(_tokenSet_1_data_,10);
 const unsigned long ncoLexer::_tokenSet_2_data_[] = { 0UL, 0UL, 2281701374UL, 134217726UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // A B C D E F G H I J K L M N O P Q R S T U V W X Y Z _ a b c d e f g 
-// h i j k l m n o p q r s t u v 
+// h i j k l m n o p q r s t 
 const ANTLR_USE_NAMESPACE(antlr)BitSet ncoLexer::_tokenSet_2(_tokenSet_2_data_,10);
 const unsigned long ncoLexer::_tokenSet_3_data_[] = { 4294966271UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // 0x0 0x1 0x2 0x3 0x4 0x5 0x6 0x7 0x8 0x9 0xb 0xc 0xd 0xe 0xf 0x10 0x11 
 // 0x12 0x13 0x14 0x15 0x16 0x17 0x18 0x19 0x1a 0x1b 0x1c 0x1d 0x1e 0x1f 
 //   ! \" # $ % & \' ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ? @ 
 // A B C D E F G H I J K L M N O P Q R S T U V W X Y Z [ 0x5c ] ^ _ ` a 
-// b c d e f g h i j k l m n o p q r s t u v 
+// b c d e f g h i j k l m n o p q r s t 
 const ANTLR_USE_NAMESPACE(antlr)BitSet ncoLexer::_tokenSet_3(_tokenSet_3_data_,16);
 const unsigned long ncoLexer::_tokenSet_4_data_[] = { 4294958079UL, 4294966271UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // 0x0 0x1 0x2 0x3 0x4 0x5 0x6 0x7 0x8 0x9 0xb 0xc 0xe 0xf 0x10 0x11 0x12 
 // 0x13 0x14 0x15 0x16 0x17 0x18 0x19 0x1a 0x1b 0x1c 0x1d 0x1e 0x1f   ! 
 // \" # $ % & \' ( ) + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ? @ A B C 
 // D E F G H I J K L M N O P Q R S T U V W X Y Z [ 0x5c ] ^ _ ` a b c d 
-// e f g h i j k l m n o p q r s t u v 
+// e f g h i j k l m n o p q r s t 
 const ANTLR_USE_NAMESPACE(antlr)BitSet ncoLexer::_tokenSet_4(_tokenSet_4_data_,16);
 const unsigned long ncoLexer::_tokenSet_5_data_[] = { 4294966271UL, 4294967291UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // 0x0 0x1 0x2 0x3 0x4 0x5 0x6 0x7 0x8 0x9 0xb 0xc 0xd 0xe 0xf 0x10 0x11 
 // 0x12 0x13 0x14 0x15 0x16 0x17 0x18 0x19 0x1a 0x1b 0x1c 0x1d 0x1e 0x1f 
 //   ! # $ % & \' ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ? @ A B 
 // C D E F G H I J K L M N O P Q R S T U V W X Y Z [ 0x5c ] ^ _ ` a b c 
-// d e f g h i j k l m n o p q r s t u v 
+// d e f g h i j k l m n o p q r s t 
 const ANTLR_USE_NAMESPACE(antlr)BitSet ncoLexer::_tokenSet_5(_tokenSet_5_data_,16);
 
